DataEvent class

Basic event structure for events between windows.

Properties

data → dynamic
The data emitted.
final
from → String
From which window it was sent.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to → String
To which window it was send.
final
type → DataEventType
The type of event, either system or user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(dynamic data) → DataEvent
Construct a new DataEvent.